diff --git a/src/knot/zone/events.c b/src/knot/zone/events.c
index 517d0338c8cf61d47d0cfc05f14550e41047935b..cf4e8955fe4fe5573f7022cde4552a57067da8d5 100644
--- a/src/knot/zone/events.c
+++ b/src/knot/zone/events.c
@@ -224,7 +224,8 @@ static int event_reload(zone_t *zone)
 		return KNOT_ERROR;
 	}
 
-	/* Apply changes in journal. */
+	/* Store zonefile serial and apply changes from the journal. */
+	zone->zonefile_serial = zone_contents_serial(contents);
 	int result = zone_load_journal(contents, zone_config);
 	if (result != KNOT_EOK) {
 		goto fail;